@@ -117,6 +117,54 @@ class TaskTestCase(unittest.TestCase):
         self.assertIn(". dummy_fail_test (x2)", detailed_iterations_data)
         self.assertNotIn("n/a", detailed_iterations_data)
 
+    def test_detailed_filter_by_scenario(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config()
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        detailed = rally("task detailed")
+        self.assertIn("Dummy.dummy_random_fail_in_atomic", detailed)
+        detailed = rally("task detailed --filter-by scenario="
+                         "Dummy.dummy_random_fail_in_atomic")
+        self.assertIn("Dummy.dummy_random_fail_in_atomic", detailed)
+        detailed = rally("task detailed --filter-by scenario=scenario.empty")
+        self.assertNotIn("Dummy.dummy_random_fail_in_atomic", detailed)
+
+    def test_detailed_filter_by_sla_failures(self):
+        rally = utils.Rally()
+        cfg = {
+            "Dummy.dummy_exception": [
+                {
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    },
+                    "sla": {
+                        "failure_rate": {"max": 0}
+                    }
+                }
+            ],
+            "Dummy.dummy_random_action": [
+                {
+                    "runner": {
+                        "type": "constant",
+                        "times": 1,
+                        "concurrency": 1
+                    }
+                }
+            ]
+        }
+        config = utils.TaskConfig(cfg)
+        try:
+            # it should be failed due to Dummy.dummy_exception
+            rally("task start --task %s" % config.filename)
+        except utils.RallyCliError:
+            pass
+        output = rally("task detailed --filter-by sla-failures")
+        self.assertIn("Dummy.dummy_exception", output)
+        self.assertNotIn("Dummy.dummy_random_action", output)
+
     def test_detailed_with_errors(self):
         rally = utils.Rally()
         cfg = {
@@ -276,10 +324,9 @@ class TaskTestCase(unittest.TestCase):
         files = []
         for i in range(3):
             rally("task start --task %s" % config.filename)
-            path = "/tmp/task_%d.json" % i
+            path = rally.gen_report_path(suffix="_results_%s" % i)
+            self.addCleanup(os.remove, path)
             files.append(path)
-            if os.path.exists(path):
-                os.remove(path)
             rally("task results", report_path=path, raw=True, no_logs=True)
 
         html_report = rally.gen_report_path(extension="html")
@@ -293,14 +340,12 @@ class TaskTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        task_result_file = "/tmp/report_42.json"
-        if os.path.exists(task_result_file):
-            os.remove(task_result_file)
+        task_result_file = rally.gen_report_path(suffix="results")
+        self.addCleanup(os.remove, task_result_file)
         rally("task results", report_path=task_result_file,
               raw=True, no_logs=True)
 
-        task_run_output = rally(
-            "task start --task %s" % config.filename)
+        task_run_output = rally("task start --task %s" % config.filename)
         task_uuid = self._get_task_uuid(task_run_output)
 
         html_report = rally.gen_report_path(extension="html")
@@ -317,11 +362,9 @@ class TaskTestCase(unittest.TestCase):
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        task_result_file = "/tmp/report_42.json"
-        if os.path.exists(task_result_file):
-            os.remove(task_result_file)
-        rally("task results", report_path=task_result_file,
-              raw=True)
+        task_result_file = rally.gen_report_path(suffix="results")
+        self.addCleanup(os.remove, task_result_file)
+        rally("task results", report_path=task_result_file, raw=True)
 
         html_report = rally.gen_report_path(extension="html")
         rally("task report --html-static %s --out %s"
